@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import Optional, Literal, Union, TypedDict, Any, overload
 from .operations import FiltrationOperator
-from pydantic import BaseModel, validator
+from pydantic import BaseModel, validator, Field
 from sqlalchemy.orm import Query
 from sqlalchemy_filters import apply_filters, apply_sort, apply_pagination
 from .table import DataTable
@@ -133,9 +133,15 @@ class ParsingData:
 class FiltrationData(BaseModel):
     to_filter: ParsingData = ParsingData()
     page_number: int = 1
-    page_size: int = None  # type: ignore
-    order_by: Optional[str] = None  # type: ignore
-    sort_by: Literal["asc", "desc"] = None  # type: ignore
+    page_size: int = Field(
+        default_factory=lambda: FiltrationData.__get_default("page_size")
+    )
+    order_by: Optional[str] = Field(
+        default_factory=lambda: FiltrationData.__get_default("order_by")
+    )
+    sort_by: Literal["asc", "desc"] = Field(
+        default_factory=lambda: FiltrationData.__get_default("sort_by")
+    )
 
     class Config:
         arbitrary_types_allowed = True
@@ -168,20 +174,23 @@ class FiltrationData(BaseModel):
         cls._default[attr] = value
 
     @classmethod
-    @validator("page_size", pre=True)
+    @validator("page_size", pre=True, always=True)
     def _pre_validate_page_size(cls, page_size: Optional[int]) -> int:
+        print("page_size")
         return page_size or cls.__get_default("page_size")
 
     @classmethod
-    @validator("order_by", pre=True)
+    @validator("order_by", pre=True, always=True)
     def _pre_validate_order_by(cls, order_by: Optional[str]) -> Optional[str]:
+        print("order_by")
         return order_by or cls.__get_default("order_by")
 
     @classmethod
-    @validator("sort_by", pre=True)
+    @validator("sort_by", pre=True, always=True)
     def _pre_validate_sort_by(
         cls, sort_by: Optional[Literal["asc", "desc"]]
     ) -> Literal["asc", "desc"]:
+        print("sort_by")
         return sort_by or cls.__get_default("sort_by")
 
     def __get_sort_spec(self) -> list[ModelSortSpec]:
